@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: pixmaped-xpm.pl,v 1.28 1999/03/07 00:13:26 root Exp $
+# $Id: pixmaped-xpm.pl,v 1.30 1999/03/09 22:08:31 root Exp root $
 
 # (c) Mark Summerfield 1999. All Rights Reserved.
 # May be used/distributed under the same terms as Perl.
@@ -17,9 +17,6 @@ sub load {
     my $loaded   = 1 ;
     my( $width, $height ) ;
 
-    &cursor( 1, 'watch' ) ;
-    &grid::status( "Loading '$filename'..." ) ;
-
     eval {
         open( XPM, $filename ) or die $! ;
         chomp( @{$Image{LINES}} = <XPM> ) ;
@@ -107,15 +104,12 @@ sub load {
     if( $@ ) {
         $loaded = 0 ;
         my $err = substr( $@, 0, rindex( $@, ' at' ) ) ;
-        message( 'Warning', 'Load',"Failed to load '$filename':\n$err" ) ;
+        message( 'Warning', 'Load',"Failed to load `$filename':\n$err" ) ;
     }
 
 
     &xpm::read_image( $filename ) if $loaded ; 
 
-    &cursor( -1 ) ;
-    &grid::status( '' ) ;
-
     $loaded ;
 }
 
@@ -126,9 +120,6 @@ sub save {
     my $filename = shift ;
     my $saved    = 1 ;
 
-    &cursor( 1, 'watch' ) ;
-    &grid::status( "Saving '$filename'..." ) ;
-
     eval {
         open( XPM, ">$filename" ) or die $! ;
 
@@ -216,15 +207,12 @@ sub save {
     if( $@ ) {
         $saved  = 0 ;
         my $err = substr( $@, 0, rindex( $@, ' at' ) ) ;
-        message( 'Warning', 'Save',"Failed to save '$filename':\n$err" ) ;
+        message( 'Warning', 'Save',"Failed to save `$filename':\n$err" ) ;
     }
 
 
     &xpm::read_image( $filename ) if $saved ; 
 
-    &cursor( -1 ) ;
-    &grid::status( '' ) ;
-
     $saved ;
 }
 
